@@ -13,7 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from six.moves.urllib import parse
+from urllib import parse
 
 from saharaclient.api import base
 
